==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/PMPLANEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PMPLANEQUIPMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMPLANEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMPLAN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANEQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMPLANEQUIPMENTID_Type", propOrder = {
    "pmplan",
    "planequipmentid"
})
public class PMPLANEQUIPMENTID_Type {

    @XmlElement(name = "PMPLAN", required = true)
    protected String pmplan;
    @XmlElement(name = "PLANEQUIPMENTID", required = true)
    protected EQUIPMENTID_Type planequipmentid;

    /**
     * Obtient la valeur de la propriété pmplan.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPMPLAN() {
        return pmplan;
    }

    /**
     * Définit la valeur de la propriété pmplan.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPMPLAN(String value) {
        this.pmplan = value;
    }

    /**
     * Obtient la valeur de la propriété planequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPLANEQUIPMENTID() {
        return planequipmentid;
    }

    /**
     * Définit la valeur de la propriété planequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPLANEQUIPMENTID(EQUIPMENTID_Type value) {
        this.planequipmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/PMPLANEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PMPLANEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMPLANEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMPLAN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANEQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMPLANEQUIPMENTID_Type", propOrder = {
    "pmplan",
    "planequipmentid"
})
public class PMPLANEQUIPMENTID_Type {

    @XmlElement(name = "PMPLAN", required = true)
    protected String pmplan;
    @XmlElement(name = "PLANEQUIPMENTID", required = true)
    protected EQUIPMENTID_Type planequipmentid;

    /**
     * Gets the value of the pmplan property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPMPLAN() {
        return pmplan;
    }

    /**
     * Sets the value of the pmplan property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPMPLAN(String value) {
        this.pmplan = value;
    }

    /**
     * Gets the value of the planequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPLANEQUIPMENTID() {
        return planequipmentid;
    }

    /**
     * Sets the value of the planequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPLANEQUIPMENTID(EQUIPMENTID_Type value) {
        this.planequipmentid = value;
    }

}
